@@ -16,24 +16,22 @@ INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patc
 (4, 1, 0, 1, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 0, 4, 'Party patch4', false, false, true, true, '2025-09-15',
+(1, true, 1, 0, 5, 'Party patch5', false, false, true, true, '2025-10-10',
 '<h5>Release notes</h5>'
 '<h6>Server:</h6><ul>'
-'<li>Fixed problem with DB save of too long startup script on Advantech devices.</li>'
-'<li>Fixed problem with some of the of server parameters being non-settable and/or not persistent when set in UI.</li>'
-'<li>Backported retention settings on DCL in DB.</li>'
-'<li>Updated bundled license.</li>'
+'<li>Fix for bug in version parsing for ICR OS 6.5.0+ (under some conditions).</li>'
+'<li>Backport: Self-signed certificate distributed to devices now contains CA certificate.</li>'
 '</ul><h6>Agents:</h6><ul>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.4');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.5');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.0.4
-Build date: 2025_09_14__15_40_55
+Build tag: v1.0.5
+Build date: 2025_10_10__14_32_08
 
 Build components:
-(mamas): v1.0.4
-(mamasbig): v1.0.4
-(mamasweb): v1.0.4
-(mamasnotify): v1.0.4');
+(mamas): v1.0.5
+(mamasbig): v1.0.5
+(mamasweb): v1.0.5
+(mamasnotify): v1.0.5');
